@@ -5,7 +5,12 @@ from . import config  # noqa: F401
 from . import errors  # noqa: F401
 from . import event  # noqa: F401
 from . import shared_state_interface  # noqa: F401
-from . import simulation_engine  # noqa: F401
-from . import simulation_message  # noqa: F401
+from . import simulator  # noqa: F401
+from . import event_message  # noqa: F401
 from . import simulation_object  # noqa: F401
 from . import utilities  # noqa: F401
+
+from .event import Event  # noqa: F401
+from .simulator import Simulator  # noqa: F401
+from .event_message import EventMessage  # noqa: F401
+from .simulation_object import SimulationObject  # noqa: F401
