@@ -17,7 +17,7 @@ import warnings
 from de_sim.config import core
 from de_sim.errors import SimulatorError
 from de_sim.event import Event
-from de_sim.simulation_message import SimulationMessage
+from de_sim.event_message import EventMessage
 from de_sim.utilities import ConcreteABCMeta, FastLogger
 from wc_utils.util.list import elements_to_str
 from wc_utils.util.misc import most_qual_cls_name, round_direct
@@ -25,11 +25,11 @@ from wc_utils.util.misc import most_qual_cls_name, round_direct
 config = core.get_config()
 
 
-# TODO(Arthur): move to engine
+# TODO(Arthur): move to simulator
 class EventQueue(object):
     """ A simulation's event queue
 
-    Stores a `SimulationEngine`'s events in a heap (also known as a priority queue).
+    Stores a `Simulator`'s events in a heap (also known as a priority queue).
     The heap is a 'min heap', which keeps the event with the smallest
     `(event_time, sending_object.name)` at the root in heap[0].
     This is implemented via comparison operations in `Event`.
@@ -40,7 +40,7 @@ class EventQueue(object):
     returned.
 
     Attributes:
-        event_heap (:obj:`list`): a `SimulationEngine`'s heap of events
+        event_heap (:obj:`list`): a `Simulator`'s heap of events
         debug_logs (:obj:`wc_utils.debug_logs.core.DebugLogsManager`): a `DebugLogsManager`
     """
 
@@ -76,9 +76,9 @@ class EventQueue(object):
             receiving_object (:obj:`SimulationObject`): the object that will receive the event; when
                 the simulation is parallelized `sending_object` and `receiving_object` will need
                 to be global identifiers.
-            message (:obj:`SimulationMessage`): a `SimulationMessage` carried by the event; its type
+            message (:obj:`EventMessage`): an :obj:`EventMessage` carried by the event; its type
                 provides the simulation application's type for an `Event`; it may also carry a payload
-                for the `Event` in its attributes.
+                for the `Event` in its `msg_field_names`.
 
         Raises:
             :obj:`SimulatorError`: if `receive_time` < `send_time`, or `receive_time` or `send_time` is NaN
@@ -95,9 +95,9 @@ class EventQueue(object):
             raise SimulatorError("receive_time < send_time in schedule_event(): {} < {}".format(
                 receive_time, send_time))
 
-        if not isinstance(message, SimulationMessage):
+        if not isinstance(message, EventMessage):
             raise SimulatorError("message should be an instance of {} but is a '{}'".format(
-                SimulationMessage.__name__, type(message).__name__))
+                EventMessage.__name__, type(message).__name__))
 
         event = Event(send_time, receive_time, sending_object, receiving_object, message)
         # As per David Jefferson's thinking, the event queue is ordered by data provided by the
@@ -194,7 +194,7 @@ class EventQueue(object):
         self.fast_debug_file_logger.fast_log(msg, sim_time=event.event_time)
 
     def render(self, sim_obj=None, as_list=False, separator='\t'):
-        """ Return the content of an `EventQueue`
+        """ Return the content of an :obj:`EventQueue`
 
         Make a human-readable event queue, sorted by non-decreasing event time.
         Provide a header row and a row for each event. If all events have the same type of message,
@@ -204,12 +204,12 @@ class EventQueue(object):
         Args:
             sim_obj (:obj:`SimulationObject`, optional): if provided, return only events to be
                 received by `sim_obj`
-            as_list (:obj:`bool`, optional): if set, return the `EventQueue`'s values in a :obj:`list`
+            as_list (:obj:`bool`, optional): if set, return the :obj:`EventQueue`'s values in a :obj:`list`
             separator (:obj:`str`, optional): the field separator used if the values are returned as
                 a string
 
         Returns:
-            :obj:`str`: String representation of the values of an `EventQueue`, or a :obj:`list`
+            :obj:`str`: String representation of the values of an :obj:`EventQueue`, or a :obj:`list`
                 representation if `as_list` is set
         """
         event_heap = self.event_heap
@@ -262,28 +262,28 @@ class EventQueue(object):
         return rv
 
 
-class SimulationObject(object):
+class BaseSimulationObject(object):
     """ Base class for simulation objects.
 
-    SimulationObject is a base class for all simulations objects. It provides basic functionality:
+    :class:`BaseSimulationObject` is a base class for all simulations objects. It provides basic functionality:
     the object's name (which must be unique), its simulation time, a queue of received events,
     and a send_event() method.
 
     Attributes:
         name (:obj:`str`): this simulation object's name, which is unique across all simulation objects
-            handled by a `SimulationEngine`
+            handled by a `Simulator`
         time (:obj:`float`): this simulation object's current simulation time
         event_time_tiebreaker (:obj:`str`): the least significant component of an object's 'sub-tme'
             priority, which orders simultaneous events received by different instances of the same
-            `ApplicationSimulationObject`
+            :obj:`SimulationObject`
         num_events (:obj:`int`): number of events processed
-        simulator (:obj:`int`): the `SimulationEngine` that uses this `SimulationObject`
+        simulator (:obj:`Simulator`): the `Simulator` that uses this :class:`BaseSimulationObject`
         debug_logs (:obj:`wc_utils.debug_logs.core.DebugLogsManager`): the debug logs
     """
     LOG_EVENTS = config['de_sim']['log_events']
 
     def __init__(self, name, start_time=0, **kwargs):
-        """ Initialize a SimulationObject.
+        """ Initialize a :class:`BaseSimulationObject`.
 
         Create its event queue, initialize its name, and set its start time.
 
@@ -292,7 +292,7 @@ class SimulationObject(object):
             start_time (:obj:`float`, optional): the earliest time at which this object can execute an event
             kwargs (:obj:`dict`): which can contain:
             event_time_tiebreaker (:obj:`str`, optional): used to break ties among simultaneous
-                events; must be unique across all instances of an `ApplicationSimulationObject`
+                events; must be unique across all instances of a :obj:`SimulationObject`
                 class; defaults to `name`
         """
         self.name = name
@@ -311,10 +311,10 @@ class SimulationObject(object):
         """ Add this object to a simulation.
 
         Args:
-            simulator (:obj:`SimulationEngine`): the simulator that will use this `SimulationObject`
+            simulator (:obj:`Simulator`): the simulator that will use this :class:`BaseSimulationObject`
 
         Raises:
-            :obj:`SimulatorError`: if this `SimulationObject` is already registered with a simulator
+            :obj:`SimulatorError`: if this :class:`BaseSimulationObject` is already registered with a simulator
         """
         if self.simulator is None:
             # TODO(Arthur): reference to the simulator is problematic because it means simulator can't be GC'ed
@@ -330,13 +330,13 @@ class SimulationObject(object):
         self.simulator = None
 
     def send_event_absolute(self, event_time, receiving_object, message, copy=False):
-        """ Send a simulation event message with an absolute event time.
+        """ Schedule an event containing an event message with an absolute event time.
 
         Args:
             event_time (:obj:`float`): the absolute simulation time at which `receiving_object` will execute the event
             receiving_object (:obj:`SimulationObject`): the simulation object that will receive and
                 execute the event
-            message (:obj:`SimulationMessage`): the simulation message which will be carried by the event
+            message (:obj:`EventMessage`): the event message which will be carried by the event
             copy (:obj:`bool`, optional): if `True`, copy the message before adding it to the event;
                 set `False` by default to optimize performance; set `True` as a safety measure to avoid
                 unexpected changes to shared objects
@@ -361,8 +361,8 @@ class SimulationObject(object):
         event_type_name = message.__class__.__name__
 
         # check that the sending object type is registered to send the message type
-        if not isinstance(message, SimulationMessage):
-            raise SimulatorError("simulation messages must be instances of type 'SimulationMessage'; "
+        if not isinstance(message, EventMessage):
+            raise SimulatorError("event messages must be instances of type 'EventMessage'; "
                                  "'{}' is not".format(event_type_name))
         if message.__class__ not in self.__class__.metadata.message_types_sent:
             raise SimulatorError("'{}' simulation objects not registered to send '{}' messages".format(
@@ -384,13 +384,13 @@ class SimulationObject(object):
                                                                              message.__class__.__name__))
 
     def send_event(self, delay, receiving_object, message, copy=False):
-        """ Send a simulation event message, specifing the event time as a delay.
+        """ Schedule an event containing an event message, specifing the event time as a delay.
 
         Args:
             delay (:obj:`float`): the simulation delay at which `receiving_object` should execute the event
             receiving_object (:obj:`SimulationObject`): the simulation object that will receive and
                 execute the event
-            message (:obj:`SimulationMessage`): the simulation message which will be carried by the event
+            message (:obj:`EventMessage`): the event message which will be carried by the event
             copy (:obj:`bool`, optional): if `True`, copy the message before adding it to the event;
                 set `False` by default to optimize performance; set `True` as a safety measure to avoid
                 unexpected changes to shared objects
@@ -409,25 +409,25 @@ class SimulationObject(object):
 
     @staticmethod
     def register_handlers(subclass, handlers):
-        """ Register a `SimulationObject`'s event handler methods.
+        """ Register a :class:`BaseSimulationObject`'s event handler methods.
 
-        The simulation engine vectors execution of a simulation message to the message's registered
+        The simulator vectors execution of an event message to the message's registered
         event handler method. The priority of message execution in an event containing multiple messages
         is determined by the sequence of tuples in `handlers`.
-        These relationships are stored in an `ApplicationSimulationObject`'s
+        These relationships are stored in a :obj:`SimulationObject`'s
         `metadata.event_handlers_dict`.
         Each call to `register_handlers` re-initializes all event handler methods.
 
         Args:
-            subclass (:obj:`SimulationObject`): a subclass of `SimulationObject` that is registering
-                the relationships between the simulation messages it receives and the methods that
+            subclass (:class:`BaseSimulationObject`): a subclass of :class:`BaseSimulationObject` that is registering
+                the relationships between the event messages it receives and the methods that
                 handle them
-            handlers (:obj:`list` of (`SimulationMessage`, `function`)): a list of tuples, indicating
-                which method should handle which type of `SimulationMessage` in `subclass`; ordered in
-                decreasing priority for handling simulation message types
+            handlers (:obj:`list` of (`EventMessage`, `function`)): a list of tuples, indicating
+                which method should handle which type of :obj:`EventMessage` in `subclass`; ordered in
+                decreasing priority for handling event message types
 
         Raises:
-            :obj:`SimulatorError`: if a `SimulationMessage` appears repeatedly in `handlers`, or
+            :obj:`SimulatorError`: if an :obj:`EventMessage` appears repeatedly in `handlers`, or
                 if a method in `handlers` is not callable
         """
         for message_type, handler in handlers:
@@ -443,41 +443,55 @@ class SimulationObject(object):
 
     @staticmethod
     def register_sent_messages(subclass, sent_messages):
-        """ Register the messages sent by a `SimulationObject` subclass
+        """ Register the messages sent by a :class:`BaseSimulationObject` subclass
 
         Calling `register_sent_messages` re-initializes all registered sent message types.
 
         Args:
-            subclass (:obj:`SimulationObject`): a subclass of `SimulationObject` that is registering
-                the types of simulation messages it sends
-            sent_messages (:obj:`list` of :obj:`SimulationMessage`): a list of the `SimulationMessage`
-                type's which can be sent by `SimulationObject`'s of type `subclass`
+            subclass (:class:`BaseSimulationObject`): a subclass of :class:`BaseSimulationObject` that is registering
+                the types of event messages it sends
+            sent_messages (:obj:`list` of :obj:`EventMessage`): a list of the :obj:`EventMessage`
+                type's which can be sent by :class:`BaseSimulationObject`'s of type `subclass`
         """
         for sent_message_type in sent_messages:
             subclass.metadata.message_types_sent.add(sent_message_type)
 
     def get_receiving_priorities_dict(self):
-        """ Get priorities of message types handled by this `SimulationObject`'s type
+        """ Get priorities of message types handled by this :obj:`SimulationObject`'s type
 
         Returns:
-            :obj:`dict`: mapping from message types handled by this `SimulationObject` to their
+            :obj:`dict`: mapping from message types handled by this :obj:`SimulationObject` to their
                 execution priorities. The highest priority is 0, and higher values have lower
                 priorities. Execution priorities determine the execution order of concurrent events
-                at a `SimulationObject`.
+                at a :obj:`SimulationObject`.
         """
         return self.__class__.metadata.event_handler_priorities
 
-    def _SimulationEngine__handle_event_list(self, event_list):
+    def __handle_event_list(self, event_list):
         """ Handle a list of simulation events, which may contain multiple concurrent events
 
-        This method's special name ensures that it cannot be overridden, and can only be called
-        from `SimulationEngine`.
+        This is a Python 'dunder' method which creates a class-private member,
+        reducing the chance that it will be accidentally called or overwritten.
+        `Simulator` refers to this method via `sim_obj._BaseSimulationObject__handle_event_list`,
+        where `sim_obj` is the simulation object that receives the event list.
+
+        If multiple event messages are received by a simulation object at the same simulation time,
+        then they are all passed in a list to the simulation object's handler.
+        This functionality, named *superposition* after the concept in physics, is important because
+        simulations must be deterministic, and to achieve that the simulation application must receive
+        all simultanous messages at once and execute them in a deterministically.
+        The alternative, in which the simulator passes simultaneous event messages in an arbitrary
+        order to a simulation object would **not** give the object sufficient information to be deterministic.
+        But if the event messages have different handlers then the simulator raises a
+        `SimulatorError` exception which says that superposition requires that the message types have
+        the same handler.
 
         Attributes:
             event_list (:obj:`list` of :obj:`Event`): the `Event` message(s) in the simulation event
 
         Raises:
-            :obj:`SimulatorError`: if a message in `event_list` has an invalid type
+            :obj:`SimulatorError`: if a message in `event_list` has an invalid type, or
+                if superposed event messages have different handlers
         """
         self.num_events += 1
 
@@ -487,15 +501,31 @@ class SimulationObject(object):
             for event in event_list:
                 self.fast_plot_file_logger.fast_log(str(event), sim_time=self.time)
 
-        # iterate through event_list, branching to handler
-        for event in event_list:
+        # if only one event message is being handled, call its handler
+        if 1 == len(event_list):
+            event = event_list[0]
             try:
                 handler = self.__class__.metadata.event_handlers_dict[event.message.__class__]
                 handler(self, event)
             except KeyError:  # pragma: no cover
                 # unreachable because of check that receiving sim
                 # obj type is registered to receive the message type
-                raise SimulatorError("No handler registered for Simulation message type: '{}'".format(
+                raise SimulatorError("No handler registered for event message type: '{}'".format(
+                    event.message.__class__.__name__))
+
+        # if multiple event messages are being handled, pass them as a list to an event handler,
+        # which is known as "superposition"
+        else:
+            try:
+                handler = self.__class__.metadata.event_handlers_dict[event_list[0].message.__class__]
+                for event in event_list[1:]:
+                    if handler != self.__class__.metadata.event_handlers_dict[event.message.__class__]:
+                        message_types = set([type(event.message).__name__ for event in event_list])
+                        raise SimulatorError(f"Superposition requires message types {message_types} have same handler")
+                handler(self, event_list)
+            except KeyError:  # pragma: no cover
+                # unreachable because of check that receiving sim obj type is registered to receive the message type
+                raise SimulatorError("No handler registered for event message type: '{}'".format(
                     event.message.__class__.__name__))
 
     @property
@@ -521,10 +551,11 @@ class SimulationObject(object):
         self.fast_debug_file_logger.fast_log(msg, sim_time=self.time)
 
 
-class ApplicationSimulationObjectInterface(object, metaclass=ABCMeta):  # pragma: no cover
+class SimulationObjectInterface(object, metaclass=ABCMeta):  # pragma: no cover
 
     @abc.abstractmethod
-    def send_initial_events(self, *args):
+    def init_before_run(self):
+        """ Perform initialization before a simulation run """
         pass
 
     @abc.abstractmethod
@@ -549,34 +580,34 @@ class SimObjClassPriority(IntEnum):
     NINTH = 9
 
     @classmethod
-    def assign_decreasing_priority(cls, aso_classes):
+    def assign_decreasing_priority(cls, so_classes):
         """ Assign decreasing simultaneous execution priorities for a list of simulation object classes
 
         Args:
-            aso_classes (:obj:`iterator` of :obj:`ApplicationSimulationObject`): an iterator over
+            so_classes (:obj:`iterator` of :obj:`SimulationObject`): an iterator over
                 simulation object classes
 
         Raises:
-            :obj:`SimulatorError`: if too many :obj:`ApplicationSimulationObject`\ s are given
+            :obj:`SimulatorError`: if too many :obj:`SimulationObject`\ s are given
         """
-        if cls.LOW < len(aso_classes):
-            raise SimulatorError(f"Too many ApplicationSimulationObjects: {len(aso_classes)}")
-        for index, aso_class in enumerate(aso_classes):
-            aso_class.set_class_priority(SimObjClassPriority(index + 1))
+        if cls.LOW < len(so_classes):
+            raise SimulatorError(f"Too many SimulationObjects: {len(so_classes)}")
+        for index, so_class in enumerate(so_classes):
+            so_class.set_class_priority(SimObjClassPriority(index + 1))
 
     def __str__(self):
         return f'{self.name}: {self.value}'
 
 
-class ApplicationSimulationObjectMetadata(object):
-    """ Metadata for an :class:`ApplicationSimulationObject`
+class SimulationObjectMetadata(object):
+    """ Metadata for an :class:`SimulationObject`
 
     Attributes:
         event_handlers_dict (:obj:`dict`): maps message_type -> event_handler; provides the event
-            handler for each message type for a subclass of `SimulationObject`
+            handler for each message type for a subclass of :class:`BaseSimulationObject`
         event_handler_priorities (:obj:`dict`): maps message_type -> message_type priority; the highest
             priority is 0, and priority decreases with increasing priority values.
-        message_types_sent (:obj:`set`): the types of messages a subclass of `SimulationObject` has
+        message_types_sent (:obj:`set`): the types of messages a subclass of :class:`BaseSimulationObject` has
             registered to send
     """
 
@@ -587,7 +618,7 @@ class ApplicationSimulationObjectMetadata(object):
         self.class_priority = SimObjClassPriority.LOW
 
 
-class ApplicationSimulationObjMeta(type):
+class SimulationObjMeta(type):
     # event handler mapping keyword
     EVENT_HANDLERS = 'event_handlers'
     # messages sent list keyword
@@ -599,24 +630,24 @@ class ApplicationSimulationObjMeta(type):
         """
         Args:
             cls (:obj:`class`): this class
-            clsname (:obj:`str`): name of the :class:`SimulationObject` subclass being created
+            clsname (:obj:`str`): name of the :class:`BaseSimulationObject` subclass being created
             superclasses (:obj:`tuple`): tuple of superclasses
-            namespace (:obj:`dict`): namespace of subclass of `ApplicationSimulationObject` being created
+            namespace (:obj:`dict`): namespace of subclass of :obj:`SimulationObject` being created
 
         Returns:
-            :obj:`SimulationObject`: a new instance of a subclass of `SimulationObject`
+            :obj:`SimulationObject`: a new instance of a subclass of :class:`BaseSimulationObject`
 
         Raises:
             :obj:`SimulatorError`: if class priority is not an `int`,
-                or if the :obj:`ApplicationSimulationObject` doesn't define `messages_sent` or `event_handlers`,
+                or if the :obj:`SimulationObject` doesn't define `messages_sent` or `event_handlers`,
                 or if handlers in `event_handlers` don't refer to methods in the
-                    :obj:`ApplicationSimulationObject`,
+                    :obj:`SimulationObject`,
                 or if `event_handlers` isn't an iterator over pairs,
-                or if a message type sent isn't a subclass of SimulationMessage,
+                or if a message type sent isn't a subclass of EventMessage,
                 or if `messages_sent` isn't an iterator over pairs.
         """
-        # Short circuit when ApplicationSimulationObject is defined
-        if clsname == 'ApplicationSimulationObject':
+        # Short circuit when SimulationObject is defined
+        if clsname == 'SimulationObject':
             return super().__new__(cls, clsname, superclasses, namespace)
 
         EVENT_HANDLERS = cls.EVENT_HANDLERS
@@ -624,9 +655,9 @@ class ApplicationSimulationObjMeta(type):
         CLASS_PRIORITY = cls.CLASS_PRIORITY
 
         new_application_simulation_obj_subclass = super().__new__(cls, clsname, superclasses, namespace)
-        new_application_simulation_obj_subclass.metadata = ApplicationSimulationObjectMetadata()
+        new_application_simulation_obj_subclass.metadata = SimulationObjectMetadata()
 
-        # use 'abstract' to indicate that an ApplicationSimulationObject should not be instantiated
+        # use 'abstract' to indicate that an SimulationObject should not be instantiated
         if 'abstract' in namespace and namespace['abstract'] is True:
             return new_application_simulation_obj_subclass
 
@@ -652,7 +683,7 @@ class ApplicationSimulationObjMeta(type):
         if CLASS_PRIORITY in namespace:
             class_priority = namespace[CLASS_PRIORITY]
             if not isinstance(class_priority, int):
-                raise SimulatorError(f"ApplicationSimulationObject '{clsname}' {CLASS_PRIORITY} must be "
+                raise SimulatorError(f"SimulationObject '{clsname}' {CLASS_PRIORITY} must be "
                                      f"an int, but '{class_priority}' is a {type(class_priority).__name__}")
 
         for superclass in superclasses:
@@ -676,13 +707,13 @@ class ApplicationSimulationObjMeta(type):
 
         # either messages_sent or event_handlers must contain values
         if (not event_handlers and not messages_sent):
-            raise SimulatorError("ApplicationSimulationObject '{}' definition must inherit or provide a "
+            raise SimulatorError("SimulationObject '{}' definition must inherit or provide a "
                                  "non-empty '{}' or '{}'.".format(clsname, EVENT_HANDLERS, MESSAGES_SENT))
         elif not event_handlers:
-            warnings.warn("ApplicationSimulationObject '{}' definition does not inherit or provide a "
+            warnings.warn("SimulationObject '{}' definition does not inherit or provide a "
                           "non-empty '{}'.".format(clsname, EVENT_HANDLERS))
         elif not messages_sent:
-            warnings.warn("ApplicationSimulationObject '{}' definition does not inherit or provide a "
+            warnings.warn("SimulationObject '{}' definition does not inherit or provide a "
                           "non-empty '{}'.".format(clsname, MESSAGES_SENT))
 
         if event_handlers:
@@ -695,12 +726,12 @@ class ApplicationSimulationObjMeta(type):
                         try:
                             handler = namespace[handler]
                         except Exception:
-                            errors.append("ApplicationSimulationObject '{}' definition must define "
+                            errors.append("SimulationObject '{}' definition must define "
                                           "'{}'.".format(clsname, handler))
                     if not isinstance(handler, str) and not callable(handler):
                         errors.append("handler '{}' must be callable".format(handler))
-                    if not issubclass(msg_type, SimulationMessage):
-                        errors.append("'{}' must be a subclass of SimulationMessage".format(msg_type.__name__))
+                    if not issubclass(msg_type, EventMessage):
+                        errors.append("'{}' must be a subclass of EventMessage".format(msg_type.__name__))
                     resolved_handers.append((msg_type, handler))
 
                 if errors:
@@ -708,44 +739,50 @@ class ApplicationSimulationObjMeta(type):
                 new_application_simulation_obj_subclass.register_handlers(
                     new_application_simulation_obj_subclass, resolved_handers)
             except (TypeError, ValueError):
-                raise SimulatorError("ApplicationSimulationObject '{}': '{}' must iterate over pairs".format(
+                raise SimulatorError("SimulationObject '{}': '{}' must iterate over pairs".format(
                     clsname, EVENT_HANDLERS))
 
         if messages_sent:
             try:
                 errors = []
                 for msg_type in messages_sent:
-                    if not issubclass(msg_type, SimulationMessage):
-                        errors.append("'{}' in '{}' must be a subclass of SimulationMessage".format(
-                            msg_type.__name__, MESSAGES_SENT))
+                    if not issubclass(msg_type, EventMessage):
+                        errors.append("'{}' in '{}' must be a subclass of EventMessage".format(
+                                      msg_type.__name__, MESSAGES_SENT))
                 if errors:
                     raise SimulatorError("\n".join(errors))
                 new_application_simulation_obj_subclass.register_sent_messages(
                     new_application_simulation_obj_subclass, messages_sent)
             except (TypeError, ValueError):
-                raise SimulatorError("ApplicationSimulationObject '{}': '{}' must iterate over "
-                                     "SimulationMessages".format(clsname, MESSAGES_SENT))
+                raise SimulatorError("SimulationObject '{}': '{}' must iterate over "
+                                     "EventMessages".format(clsname, MESSAGES_SENT))
 
         # return the class to instantiate it
         return new_application_simulation_obj_subclass
 
 
-class AppSimObjAndABCMeta(ApplicationSimulationObjMeta, ConcreteABCMeta):
+class SimulationObjectAndABCMeta(SimulationObjMeta, ConcreteABCMeta):
     """ A concrete class based on two Meta classes to be used as a metaclass for classes derived from both
     """
     pass
 
 
-class ApplicationSimulationObject(SimulationObject, ApplicationSimulationObjectInterface,
-                                  metaclass=AppSimObjAndABCMeta):
+class SimulationObject(BaseSimulationObject, SimulationObjectInterface, metaclass=SimulationObjectAndABCMeta):
     """ Base class for all simulation objects in a simulation
 
     Attributes:
-        metadata (:obj:`ApplicationSimulationObjectMetadata`): metadata for event message sending and handling,
-            initialized by `AppSimObjAndABCMeta`
+        metadata (:obj:`SimulationObjectMetadata`): metadata for event message sending and handling,
+            initialized by `SimulationObjectAndABCMeta`
     """
 
-    def send_initial_events(self, *args):
+    def init_before_run(self):
+        """ Perform initialization before a simulation run
+
+        If a simulation object defines `init_before_run`, it will be called by the simulator just before
+        simulation begins, after all simulation objects have been created and loaded.
+        A simulation object that wishes to schedule initial events for itself or for other objects in the simulation
+        should do so in `init_before_run`. It can also perform any other initialization in the method.
+        """
         pass  # pragma: no cover
 
     def get_state(self):
@@ -753,13 +790,13 @@ class ApplicationSimulationObject(SimulationObject, ApplicationSimulationObjectI
 
     @classmethod
     def set_class_priority(cls, priority):
-        """ Set the execution priority for simulation object classes, `class_priority`
+        """ Set the execution priority for a simulation object class, `class_priority`
 
-        Use this to set the `class_priority` of a subclass of :obj:`SimulationObject` after it
+        Use this to set the `class_priority` of a subclass of :class:`BaseSimulationObject` after it
             has been constructed.
 
         Args:
             priority (:obj:`SimObjClassPriority`): the desired `class_priority` for a subclass
-                of :obj:`SimulationObject`
+                of :class:`BaseSimulationObject`
         """
-        setattr(cls.metadata, ApplicationSimulationObjMeta.CLASS_PRIORITY, priority)
+        setattr(cls.metadata, SimulationObjMeta.CLASS_PRIORITY, priority)
