@@ -5,19 +5,21 @@
 :License: MIT
 """
 
-from de_sim.simulation_object import ApplicationSimulationObject, SimObjClassPriority
+from de_sim.simulation_object import SimObjClassPriority
 from de_sim.testing.some_message_types import InitMsg, Eg1
+import de_sim
+
 
 ALL_MESSAGE_TYPES = [InitMsg, Eg1]
 TEST_SIM_OBJ_STATE = 'Test SimulationObject state'
 
 
-class ExampleSimulationObject(ApplicationSimulationObject):
+class ExampleSimulationObject(de_sim.SimulationObject):
 
     def __init__(self, name, **kwargs):
         super().__init__(name, **kwargs)
 
-    def send_initial_events(self, *args):
+    def init_before_run(self, *args):
         pass  # pragma: no cover
 
     def get_state(self):
@@ -36,7 +38,7 @@ class ExampleSimulationObject(ApplicationSimulationObject):
     class_priority = SimObjClassPriority.HIGH
 
 
-class ImproperlyRegisteredSimulationObject(ApplicationSimulationObject):
+class ImproperlyRegisteredSimulationObject(de_sim.SimulationObject):
 
     # register the event handler for each type of message received
     event_handlers = [(Eg1, 'handler')]
@@ -44,7 +46,7 @@ class ImproperlyRegisteredSimulationObject(ApplicationSimulationObject):
     # register the message types sent
     messages_sent = [InitMsg]
 
-    def send_initial_events(self, *args):
+    def init_before_run(self, *args):
         pass  # pragma: no cover
 
     def get_state(self):
